<?php
// $Id: weblinks.admin.inc,v 1.15 2008/07/16 03:44:30 rmiddle Exp $

/**
 * @file
 * Settings form.
 */

/**
 * Module settings page.
 */
function weblinks_admin_settings(&$form_state) {
  $vocabs = taxonomy_get_vocabularies('weblinks');
  if (count($vocabs) > 1) {
    $avail_vocs = array();
    foreach ($vocabs as $vid => $vocabulary) {
      $avail_vocs[$vid] = check_plain($vocabulary->name);
    }
    ksort($avail_vocs);
    $form['weblinks_nav_vocabulary'] = array(
      '#type' => 'radios',
      '#title' => t('Vocabulary to use for Weblinks'),
      '#default_value' => variable_get('weblinks_nav_vocabulary', ''),
      '#options' => $avail_vocs,
      '#required' => true,
      '#prefix' => '<div class="weblinks-radios">',
      '#suffix' => '</div><div class="clear-block"></div>',
      '#weight' => -20,
      );
  }
  $form['weblinks_external'] = array(
    '#type' => 'radios',
    '#title' => t('Open links in a new window'),
    '#default_value' => variable_get("weblinks_external", true),
    '#options' => array(1 => 'yes', 0 => 'no'),
    '#required' => FALSE,
    '#description' => t('Recommended to keep your vistors on your site.'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    '#weight' => -17,
    );

  $form['weblinks_pagedesc'] = array(
    '#type' => 'textarea',
    '#title' => t('Page information'),
    '#rows' => 5,
    '#default_value' => variable_get("weblinks_pagedesc", null),
    '#description' => t('This description will appear at the top of the links page.  It will be filtered by your default input format.'),
    '#required' => false,
    '#weight' => -16,
    );

  $form['weblinks_simplelinks'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Simple Links'),
    '#default_value' => variable_get("weblinks_simplelinks", false),
    '#description' => t('Enable this if you want the links to appear on the main page, otherwise, your users will have to click on the category to view the links. The depth of the links to be displayed is specified below.'),
    '#required' => TRUE,
    '#weight' => -15,
  );

  $form['weblinks_empty_text'] = array(
    '#type' => 'textarea',
    '#title' => t('Empty category text'),
    '#rows' => 2,
    '#default_value' => variable_get('weblinks_empty_text', null),
    '#description' => t('This text will appear when a category is empty. Leave it blank for no text. It will be filtered by your default input format.'),
    '#required' => false,
    '#weight' => -14,
    );

  $sort_options = array(
    'standard' => 'Normal Drupal - by weight, sticky, created date.',
    'title' => 'Legacy - by weight and title.',
    );
  $form['weblinks_page_sort'] = array(
    '#type' => 'radios',
    '#options' => $sort_options,
    '#title' => t('Page Sort order'),
    '#default_value' => variable_get('weblinks_page_sort', 'title'),
    '#description' => t('This determines how the links page will sort the links.'),
    '#required' => false,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    '#weight' => -12,
  );

  // @TODO: move this to block settings.
  $form['weblinks_block_sort'] = array(
    '#type' => 'radios',
    '#options' => $sort_options,
    '#title' => t('Block Sort order'),
    '#default_value' => variable_get('weblinks_block_sort', 'title'),
    '#description' => t('This determines how the links block will sort the links.'),
    '#required' => false,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    '#weight' => -11,
  );
  $form['weblinks_urlnode'] = array(
    '#type' => 'radios',
    '#title' => t('Links lead URL or to Web Link node'),
    '#default_value' => variable_get("weblinks_urlnode", 'url'),
    '#description' => t('Most people will want to leave this as URL. Specifying "node" makes it easier to edit the links, but requires an additional click to follow the link.'),
    '#options' => array('url' => 'URL', 'node' => 'node'),
    '#required' => FALSE,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    '#weight' => -10,
  );

  // @TODO: move this to block settings.
  $form['weblinks_block_urlnode'] = array(
    '#type' => 'radios',
    '#title' => t('Block links lead URL or to Web Link node'),
    '#default_value' => variable_get("weblinks_block_urlnode", 'url'),
    '#description' => t('See the previous description.'),
    '#options' => array('url' => 'URL', 'node' => 'node'),
    '#required' => FALSE,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    '#weight' => -9,
  );
  $form['weblinks_catdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link category descriptions'),
    '#default_value' => variable_get("weblinks_catdesc", true),
    '#description' => t('Generally recommended.'),
    '#required' => FALSE,
    '#weight' => -8,
  );
  $form['weblinks_subcatdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link sub-category descriptions'),
    '#default_value' => variable_get("weblinks_subcatdesc", false),
    '#description' => t('Generally recommended if you are showing more than the top level of links..'),
    '#required' => FALSE,
    '#weight' => -7,
  );
  $form['weblinks_linkdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display individual link descriptions'),
    '#default_value' => variable_get("weblinks_linkdesc", true),
    '#description' => t('Generally recommended.'),
    '#required' => FALSE,
    '#weight' => -6,
  );
  $form['weblinks_linkinfo'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link information'),
    '#default_value' => variable_get("weblinks_linkinfo", true),
    '#description' => t('This displays link author, publish date, and revision date'),
    '#required' => FALSE,
    '#weight' => -5,
  );
  $form['weblinks_nofollow'] = array(
    '#type' => 'checkbox',
    '#title' => t('Spam link deterrent'),
    '#default_value' => variable_get('weblinks_nofollow', false),
    '#description' => t('If enabled, Drupal will add rel="nofollow" to all links, as a measure to reduce the effectiveness of spam links. Note: this will also prevent valid links from being followed by search engines, therefore it is likely most effective when enabled for anonymous users.'),
    '#weight' => -4,
    );
  $form['weblinks_maxfrontdepth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum category depth (front page)'),
    '#default_value' => variable_get("weblinks_maxfrontdepth", true),
    '#description' => t('This controls how many subcategories, if any, will display on the main links page. Blank, zero (0), and one (1) will all show only the top level.'),
    '#required' => FALSE,
    '#size' => 2,
    '#weight' => -3,
  );
  $form['weblinks_maxdepth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum category depth'),
    '#default_value' => variable_get("weblinks_maxdepth", true),
    '#description' => t('This controls how many subcategories, if any, will display on other links pages.'),
    '#required' => FALSE,
    '#size' => 2,
    '#weight' => -2
  );
  $form['weblinks_clickthru'] = array(
    '#type' => 'textfield',
    '#title' => t('User click through'),
    '#default_value' => variable_get("weblinks_clickthru", NULL),
    '#description' => t('How many clicks a user can make before all the menus are automatically expanded. Leave blank if you do not want to set a limit.'),
    '#required' => FALSE,
    '#size' => 2,
    '#weight' => -1,
  );

  $form['categories'] = array(
    '#type' => 'fieldset',
    '#title' => t('Category settings'),
    '#collapsible' => true,
    '#collapsed' => false,
    '#weight' => 0,
  );
  // Get the weblinks categories to add to the blogroll
  $result = db_query('SELECT tid, name FROM {term_data} WHERE vid = %d ORDER BY weight ASC, name ASC', _weblinks_get_vocid());

  while ($row = db_fetch_object($result)) {
    // Set which link categories get displayed on the links page

    $form['categories'][$row->tid] = array(
      '#type' => 'fieldset',
      '#title' => $row->name,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#weight' => 0,
    );

    $form['categories'][$row->tid]['weblinks_page_'. $row->tid] = array(
      '#type' => 'checkbox',
      '#title' => $row->name,
      '#default_value' => variable_get('weblinks_page_'. $row->tid, 1),
      '#required' => FALSE,
      '#description' => t('Check to enable this category to display on the main weblinks page.'),
    );

    // Set the maximum number of links to display for each category
    $form['categories'][$row->tid]['weblinks_maxdisp_'. $row->tid] = array(
      '#type' => 'textfield',
      '#title' => t('Maximum links to display'),
      '#default_value' => variable_get('weblinks_maxdisp_'. $row->tid, NULL),
      '#size' => 2,
      '#required' => FALSE,
      '#description' => t('Leave blank if you would not like to limit the number of links displayed'),
    );
  }
  return system_settings_form($form);
}
